import { IOBuffer } from 'iobuffer';
import { FlagParameters } from './utility/headerUtils';
/**
 * Old-format File-header parsing.
 * @param buffer spc buffer.
 * @param  prev `{parameters,fileversion}`
 * @return  file metadata
 */
export declare class TheOldHeader {
    fileVersion: number;
    parameters: FlagParameters;
    exponentY: number;
    numberPoints: number;
    startingX: number;
    endingX: number;
    xUnitsType: string | number;
    yUnitsType: string;
    date: string;
    resolutionDescription: string;
    peakPointNumber: number;
    scans: number;
    spare: number[];
    memo: string;
    xyzLabels: string;
    constructor(buffer: IOBuffer, prev: {
        parameters: FlagParameters;
        fileVersion: number;
    });
}
/**
 * New format file-header parsing.
 * @param buffer spc buffer.
 * @param  prev `{parameters,fileversion}`
 * @return  file metadata
 */
export declare class TheNewHeader {
    fileVersion: number;
    parameters: FlagParameters;
    experimentType: string;
    exponentY: number;
    numberPoints: number;
    startingX: number;
    endingX: number;
    spectra: number;
    xUnitsType: string | number;
    yUnitsType: string;
    zUnitsType: string | number;
    postingDisposition: number;
    date: string;
    resolutionDescription: string;
    sourceInstrumentDescription: string;
    peakPointNumber: number;
    spare: number[];
    memo: string;
    xyzLabels: string;
    logOffset: number;
    modifiedFlag: number;
    processingCode: number;
    calibrationLevel: number;
    subMethodSampleInjectionNumber: number;
    concentrationFactor: number;
    methodFile: string;
    zSubIncrement: number;
    wPlanes: number;
    wPlaneIncrement: number;
    wAxisUnits: string | number;
    reserved: string;
    constructor(buffer: IOBuffer, prev: {
        parameters: FlagParameters;
        fileVersion: number;
    });
}
export type Header = TheOldHeader | TheNewHeader;
/**
 * File-header parsing - First 512/256 bytes (new/old format).
 * @param buffer SPC buffer.
 * @return File-header object
 */
export declare function fileHeader(buffer: IOBuffer): Header;
//# sourceMappingURL=fileHeader.d.ts.map