import { MeasurementXY, MeasurementXYVariables } from 'cheminfo-types';
import { IOBuffer } from 'iobuffer';
import { Header } from '../fileHeader';
/**
 * Use cheminfo type for better UI compatibility
 */
export type Spectrum = MeasurementXY;
/**
 * Gets the Subfile flags.
 *
 * @param  flag First byte of the subheader.
 * @return The parameters.
 */
export declare class SubFlagParameters {
    changed: boolean;
    noPeakTable: boolean;
    modifiedArithmetic: boolean;
    constructor(flag: number);
}
/**
 * Parses the subheader (header of the subfile)
 *
 * @param buffer SPC buffer.
 * @return subheader object
 */
export declare class SubHeader {
    parameters: SubFlagParameters;
    exponentY: number;
    indexNumber: number;
    startingZ: number;
    endingZ: number;
    noiseValue: number;
    numberPoints: number;
    numberCoAddedScans: number;
    wAxisValue: number;
    reserved: string;
    constructor(buffer: IOBuffer);
}
/**
 * Set the X and Y axis (object with labels, values etc.)
 * @param x
 * @param y
 * @param fileHeader
 * @return object with x and y as axis.
 */
export declare function setXYAxis(x: Float64Array, y: Float64Array, fileHeader: Header): MeasurementXYVariables<import("cheminfo-types").DoubleArray>;
//# sourceMappingURL=shared.d.ts.map