"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parse = void 0;
const iobuffer_1 = require("iobuffer");
const newDataBlock_1 = require("./dataBlock/newDataBlock");
const oldDataBlock_1 = require("./dataBlock/oldDataBlock");
const fileHeader_1 = require("./fileHeader");
const logBlock_1 = require("./logBlock");
/**
 * Parses an SPC file.
 *
 * @param  buffer SPC file buffer.
 * @return JSON-like object with information contained in the SPC file.
 */
function parse(buffer) {
    const ioBuffer = new iobuffer_1.IOBuffer(buffer);
    const meta = (0, fileHeader_1.fileHeader)(ioBuffer);
    if (meta instanceof fileHeader_1.TheNewHeader) {
        //new format
        const spectra = (0, newDataBlock_1.newDataBlock)(ioBuffer, meta);
        const logs = meta.logOffset !== 0 ? (0, logBlock_1.readLogBlock)(ioBuffer, meta.logOffset) : null;
        return { meta, spectra, logs };
    }
    else {
        //old format
        return {
            meta,
            spectra: (0, oldDataBlock_1.oldDataBlock)(ioBuffer, meta),
        };
    }
}
exports.parse = parse;
//# sourceMappingURL=parse.js.map