import { Header } from '../fileHeader';
/**
 * For now "ir" is ir-only spectra
 * uv could be: uv (only), uv-vis, uv-vis-nir, vis-nir.
 */
export type SpectraType = 'ir' | 'uv' | 'raman' | 'mass' | 'other';
/**
 * Inspects properties and tries to classify the spectra
 * For the most common spectra types
 * @param data the parsed data
 * @returns string describing the type of spectra ([[`SpectraType`]]) or "General" if unsure.
 */
export declare function guessSpectraType(meta: Header): SpectraType;
type Regions = 'uv' | 'ir' | 'other';
/**
 * Further classify an X axis that is using "wavenumber" as uv or ir.
 * @param data - the parsed file (a jsonlike object)
 * @returns
 */
export declare function uvOrIR(meta: Header, xUnit: 'micrometer' | 'nanometer' | 'wavenumber'): Regions;
/**
 * @param lb -  lower boundary in _nanometers_
 * @return type of spectra
 */
export declare function getRegion(lb: number): Regions;
/**
 * Converts micrometers or wavenumber units to nanometers
 * This allows a unique way to determine the spectra region (using nanometers).
 * @param x - value
 * @param from - input unit to convert
 * @return equivalent in nanometers
 */
export declare function unitToNano(x: number, from: 'micrometer' | 'wavenumber'): number;
export {};
//# sourceMappingURL=guessSpectraType.d.ts.map